#
# spec file for package netty-tcnative
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}
Name:           netty-tcnative
Version:        2.0.36
Release:        150200.3.7.3
Summary:        Fork of Tomcat Native with improved OpenSSL and mavenized build
License:        Apache-2.0
URL:            https://github.com/netty/netty/wiki/Forked-Tomcat-Native
Source0:        https://github.com/netty/netty-tcnative/archive/%{name}-parent-%{namedversion}.tar.gz
Source1:        fixLibNames.patch.in
Source2:        https://repo1.maven.org/maven2/io/netty/netty-jni-util/0.0.3.Final/netty-jni-util-0.0.3.Final-sources.jar
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  java-devel >= 1.8
BuildRequires:  libtcnative-1-0
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(kr.motd.maven:os-maven-plugin)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
Requires:       libtcnative-1-0

%description
netty-tcnative is a fork of Tomcat Native. It includes a set of changes
contributed by Twitter, Inc, such as:
 *  Simplified distribution and linkage of native library
 *  Complete mavenization of the project
 *  Improved OpenSSL support
To minimize the maintenance burden, we create a dedicated branch for each stable
upstream release and apply our own changes on top of it, while keeping the
number of maintained branches to minimum

%package javadoc
Summary:        API documentation for %{name}
BuildArch:      noarch

%description javadoc
%{summary}.

%prep
%setup -q -n %{name}-%{name}-parent-%{namedversion}
patch=`mktemp`
sed "s;@PATH@;%{_libdir};g" < %{SOURCE1} > $patch
patch -p1 < $patch

# Build only the openssl-dynamic module
%pom_disable_module openssl-static
%pom_disable_module boringssl-static
%pom_disable_module libressl-static

%pom_remove_plugin :japicmp-maven-plugin .
%pom_remove_plugin :maven-enforcer-plugin .
%pom_remove_plugin :maven-antrun-plugin . openssl-dynamic
%pom_remove_plugin :maven-hawtjni-plugin openssl-dynamic
%pom_xpath_remove pom:project/pom:profiles openssl-dynamic

%pom_remove_dep io.netty:netty-jni-util
%pom_remove_plugin :maven-dependency-plugin
mkdir -p target/netty-jni-util
unzip %{SOURCE2} -d target/netty-jni-util

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%files javadoc -f .mfiles-javadoc

%changelog
* Mon Apr 25 2022 fstrba@suse.com
- Remove dependency on separate package netty-jni-util-sources
- Unpack the sources to their right place without passing through
  maven mechanisms
- This version fixes bsc#1198792
* Wed Mar 23 2022 fstrba@suse.com
- Build with java source and target levels 1.8
* Wed Mar 24 2021 fstrba@suse.com
- Update to the 2.0.36 Final
  * fix build in factory
  * new dependency on netty-jni-util-sources
* Wed Mar 24 2021 fstrba@suse.com
- Update to the 2.0.36 Final
  * Includes many changes, from which the relevalt ones are:
    + Upgrade to OpenSSL 1.1.1i
    + Update to latest openssl version for static build
    + Update to LibreSSL 3.1.4
    + Update to latest stable libressl release
    + Update to openssl 1.1.1g
    + OpenSSL 1.1.1d
    + Update to libressl 2.9.3
    + Upgrade to openssl 1.1.1c
    + Update OpenSSL to 1.1.1b and LibreSSL to 2.8.3
    + Cleanup BoringSSL TLSv1.3 support and consistent handle empty ciphers.
    + Support TLSv1.3 with compiling against boringssl
    + Return 0 for SSL_OP_NO_TLSv1_3 when TLSv1.3 is not supported.
    + Add support for TLSv1.3 when compiled against openssl 1.1.1
    + Allow to load a private key from the OpenSSL engine.
    + Support KeyManagerFactory if compiled against OpenSSL < 1.0.2 but using OpenSSL >= 1.0.2 at runtime.
    + Update to libressl 2.6.4
    + Update to openssl 1.0.2n
    + Update to libressl 2.5.5
    + Allow to compile with openssl 1.0.1
    + Update deprecated methods and OpenSSL api changes to allow building with OpenSSL 1.1.0e
    + Update to libressl 2.4.5
    + Update openssl to 1.0.2k
    + Ensure we can compile against openssl 1.1.x and libressl 2.5.x as well.
    + Update libressl to 2.4.2
    + Update openssl to 1.0.2j
    + Update openssl to 1.0.2i
  * fix build in factory
* Thu Jan  9 2020 fstrba@suse.com
- Update to the 1.1.33 Final26, the last version of 1.1 series
- Use directement libtcnative-1-0 package, since it is API
  compatible and supports openssl 1.1.x
- Removed patch:
  * i388aprFix.patch
    + Integrated upstream
* Thu Nov 14 2019 fstrba@suse.com
- Initial packaging of netty-tcnative 1.1.30
